dot-wt_col_types.Rd
Assign correct column types for reports, varying by sensor
.wt_col_types(sensor_id = NULL)
Character. Sensor type (e.g. "PC", "ARU"). Determines type overrides for columns that differ between sensors.