Get a project summary from WildTrax
wt_get_projects.RdObtain a table listing projects that the user is able to download data for.
Value
A data frame listing the projects that the user can download data for, including: project name, id, year, number of tasks and project status.
Examples
if (FALSE) { # \dontrun{
# Authenticate first:
wt_auth()
wt_get_projects(sensor = "ARU")
} # }